@@ -187,7 +187,6 @@ Es gibt \$hostCntGood Computer die erfolgreich gesichert wurden, mit insgesamt:
     <td align="center"> Letzte Aktion </td></tr>
 \$strGood
 </table>
-<br><br>
 \${h2("Computer ohne Backups")}
 <p>
 Es gibt \$hostCntNone Computer ohne Backups !!!
@@ -382,7 +381,6 @@ $Lang{BackupPC__Queue_Summary} = "BackupPC: Warteschlange bersicht";
 # --------------------------------
 $Lang{Backup_Queue_Summary} = <<EOF;
 \${h1("Backup Warteschlangenbersicht")}
-<br><br>
 \${h2("bersicht Benutzerauftrge in der Warteschlange")}
 <p>
 Die folgenden Benutzerauftrge sind eingereiht:
@@ -393,7 +391,6 @@ Die folgenden Benutzerauftrge sind eingereiht:
     <td> Benutzer </td></tr>
 \$strUser
 </table>
-<br><br>
 
 \${h2("bersicht Hintergrundauftrge in der Warteschlange")}
 <p>
@@ -405,7 +402,6 @@ Die folgenden Hintergrundauftrge sind eingereiht:
     <td> Benutzer </td></tr>
 \$strBg
 </table>
-<br><br>
 \${h2("bersicht Kommandoauftrge in der Warteschlange")}
 <p>
 Die folgenden Kommandoauftrge sind eingereiht:
@@ -703,9 +699,7 @@ Klicken Sie auf die Backupnummer um die Dateien zu durchsuchen und bei Bedarf wi
 
 \$restoreStr
 </p>
-<br><br>
 \${h2("Xfer Fehler bersicht - bitte kontrollieren")}
-<br><br>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Typ </td>
@@ -717,7 +711,6 @@ Klicken Sie auf die Backupnummer um die Dateien zu durchsuchen und bei Bedarf wi
 </tr>
 \$errStr
 </table>
-<br><br>
 
 \${h2("Datei Gre/Anzahl Wiederverwendungsbersicht")}
 <p>
@@ -744,7 +737,6 @@ Leere Dateien und eventuelle Dateifehler sind nicht in den Summen enthalten.
 </tr>
 \$sizeStr
 </table>
-<br><br>
 
 \${h2("Kompressions bersicht")}
 <p>
@@ -767,7 +759,6 @@ Kompressionsergebnisse fr bereits im Backup-Pool vorhandene und fr neu komprimie
 </tr>
 \$compStr
 </table>
-<br><br>
 EOF
 
 $Lang{Host__host_Archive_Summary} = "BackupPC: Host \$host Archivbersicht";
@@ -904,7 +895,7 @@ Diese Ansicht zeigt alle unterschiedlichen Versionen der Dateien in den Datensic
 <li> Whlen Sie hier auf einen Verzeichnis Namen: (\$Lang->{DirHistory_dirLink}) um Verzeichnisse anzuzeigen.
 <li> Klicken Sie auf eine Dateiversion (\$Lang->{DirHistory_fileLink}0,
      \$Lang->{DirHistory_fileLink}1, ...) fr einen Download der Datei.
-<li> Dateien mit dem gleichen Inhalt in verschiedenen Datensicherungen haben die gleiche Versionsnummer.
+<li> Dateien mit dem gleichen Inhalt in verschiedenen Datensicherungen haben die gleiche Versionsnummer (PleaseTranslateThis: except between v3 and v4 backups).
 <li> Dateien oder Verzeichnisse, die in einer Datensicherung nicht vorhanden sind, haben dort keinen Eintrag.
 <li> Dateien mit der gleichen Version knnen unterschiedliche Attribute haben. Whlen Sie die Datensicherungsnummer um die Attribute anzuzeigen.
 </ul>
